@@ -1,7 +1,6 @@
 
 from django.conf.urls.defaults import url, patterns
-
-from feedback_form import views, forms
+from feedback_form import views
 
 urlpatterns = patterns('',
     url(r'^$', views.ContactFormView.as_view(), name="contact"),
